@@ -465,12 +465,6 @@ yylex(int cf)
 				POP_STATE();
 				*wp++ = CSUBST;
 				*wp++ = /*{*/ '}';
-			} else if (c == '|') {
-				*wp++ = SPAT;
-			} else if (c == '(') {
-				*wp++ = OPAT;
-				*wp++ = ' ';	/* simile for @ */
-				PUSH_STATE(SPATTERN);
 			} else
 				goto Sbase2;
 			break;
@@ -578,19 +572,6 @@ yylex(int cf)
 			}
 			break;
 
-		  case SPATTERN:	/* in *(...|...) pattern (*+?@!) */
-			if ( /*(*/ c == ')') {
-				*wp++ = CPAT;
-				POP_STATE();
-			} else if (c == '|') {
-				*wp++ = SPAT;
-			} else if (c == '(') {
-				*wp++ = OPAT;
-				*wp++ = ' ';	/* simile for @ */
-				PUSH_STATE(SPATTERN);
-			} else
-				goto Sbase2;
-			break;
 		}
 	}
 Done:
